import { OnInit, SimpleChanges, OnChanges, EventEmitter, OnDestroy } from '@angular/core';
import { Viewer as ArViewer, LoadResult, SearchOptions, CancellationToken, SearchStatus } from '@grapecity/activereports/viewer';
import { RDLReportDefinition } from 'rdlx-model';
import { ExportResult, FontDescriptor } from '@grapecity/ar-js-viewer/ExportPanel';
import { SearchFeature } from '@grapecity/viewer-core';
import { ViewerMouseMode, ViewerViewMode, ViewMode, ViewerRenderMode, ViewerZoomMode, DocumentLoadEventArgs, ReportLoadEventArgs, ReportSettings, Toolbar, HistoryApi } from '@grapecity/ar-js-viewer';
import { SearchResult } from '@grapecity/viewer-core/features/search';
import { Export } from '../export-injectiontoken';
export declare type IReport = RDLReportDefinition | string;
export declare class ViewerComponent implements OnInit, OnChanges, OnDestroy {
    private readonly supportedExports?;
    private _viewer;
    private _initProps;
    private readonly supportedExportKeys;
    constructor(supportedExports?: Export[]);
    width: string;
    height: string;
    language?: string;
    availableExports?: string[];
    mouseMode?: ViewerMouseMode;
    renderMode?: ViewerRenderMode;
    viewMode?: ViewerViewMode | ViewMode;
    zoom?: ViewerZoomMode;
    fullscreen?: boolean;
    toolbarVisible?: boolean;
    sidebarVisible?: boolean;
    errorHandler?: () => void;
    init: EventEmitter<ViewerComponent>;
    reportLoaded: EventEmitter<ReportLoadEventArgs>;
    documentLoaded: EventEmitter<DocumentLoadEventArgs>;
    private _propSetters;
    private _disposables;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    readonly ref: ArViewer;
    private initViewer;
    /**
     * Opens report from file or as definition (json string)).
     *
     * @param report  The report template. Can be report URI, or report definition, or instance of PageReport class.
     * @param settings  Additional settings for report (name, parameters).
     */
    open(report: IReport, settings?: Partial<ReportSettings>): Promise<LoadResult>;
    /**
     * Exports currently displayed report to specified output format. Returns object which contains
     * result data as blob object | string and download function. So you could either use this blob object or download file immediately.
     * Please note that you can specify settings in PDF export as plain list
     * (like **{title: 'Title', author: 'Author Name', ownerPassword: '1'}** etc...
     *
     * ```javascript
     * var options = {filename:"Invoice List"};
     * var cancelCallback = function(){
     *     return false; // continue export. Return true to cancel export process
     * }
     * viewer.export('pdf', options, {cancel: cancelCallback }).then(result => doSmthWithBlob(result.data));
     * //or you can download file
     * viewer.export('pdf', options, {cancel: cancelCallback }).then(result => result.download('Invoice List'));
     * ```
     *
     * @param format  Export format identifier. One of 'pdf', 'xlsx' or 'html'.
     * @param settings  Format specific export settings.
     * @param params  Additional export customization.
     */
    export(format: string, settings: any[], params?: {
        cancel?: () => boolean;
    }): Promise<ExportResult>;
    /**
     * Resets current viewer document
     */
    resetDocument(): Promise<void>;
    /**
     * Prints currently displayed report.
     */
    print(): void;
    /** Gets current page number (1-based). Returns 0 if no document loaded. */
    readonly currentPage: number;
    /** Gets the total number of pages available in report. */
    readonly pageCount: number;
    /** Provides access to the "history" API. */
    readonly history: HistoryApi;
    /** Gets the toolbar API */
    readonly toolbar: Toolbar;
    /** Navigates to the first page. */
    goToFirstPage(): void;
    /** Navigates to the previous page. */
    goToPrevPage(): void;
    /** Navigates to the next page. */
    goToNextPage(): void;
    /** Navigates to the last page. */
    goToLastPage(): void;
    /** Navigates to the specified page (starting from 1). */
    goToPage(pageNumber: number): void;
    /** Performs backToParent action which will return user to parent report. */
    backToParent(): void;
    /** Performs refresh operation in report (re-render report). */
    refresh(): void;
    /** Gets **true** if backToParent command is applicable to current document. */
    readonly canBackToParent: boolean;
    /**
     * Register specified fonts in CSS and pdf export. Helps display export correctly on machines where fonts can be missed.
     */
    registerFont(...fonts: FontDescriptor[]): Promise<void>;
    /**
     * Performs search operation in currently rendered report. Allows you to create your own custom search pane.
     */
    search(options: SearchOptions, resultFn: (result: SearchResult) => void, progressFn?: (progress: {
        pageIndex: number;
        pageCount: number | null;
    }) => void, cancel?: CancellationToken): Promise<SearchStatus>;
    /**
     * Highlights the search result returned by a search method.
     */
    highlight(result: SearchFeature.SearchResult | null): Promise<void>;
}
